==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d0/d27/classVehicleGroupWindow.js <==
var classVehicleGroupWindow =
[
    [ "ListColumns", "d0/d27/classVehicleGroupWindow.html#ad4d7cb0ccb95e92e15690c8bf9f4716d", [
      [ "VGC_NAME", "d0/d27/classVehicleGroupWindow.html#ad4d7cb0ccb95e92e15690c8bf9f4716da70b8b6aad8471d8e16cb47e0dfb5accf", null ],
      [ "VGC_PROTECT", "d0/d27/classVehicleGroupWindow.html#ad4d7cb0ccb95e92e15690c8bf9f4716da875b355759fe13acdcbb0fd2c62a4c50", null ],
      [ "VGC_AUTOREPLACE", "d0/d27/classVehicleGroupWindow.html#ad4d7cb0ccb95e92e15690c8bf9f4716da6187b84b9f40c7905f0ef8b7b5ef3a43", null ],
      [ "VGC_PROFIT", "d0/d27/classVehicleGroupWindow.html#ad4d7cb0ccb95e92e15690c8bf9f4716da5e1e385471ae13f1b57256439408c94d", null ],
      [ "VGC_NUMBER", "d0/d27/classVehicleGroupWindow.html#ad4d7cb0ccb95e92e15690c8bf9f4716dafd744d7ed56ce8ce9f6fe7661c740a06", null ],
      [ "VGC_END", "d0/d27/classVehicleGroupWindow.html#ad4d7cb0ccb95e92e15690c8bf9f4716da202d160f66f32764dae33bb5775f287e", null ]
    ] ],
    [ "VehicleGroupWindow", "d0/d27/classVehicleGroupWindow.html#aefbca24fd6c289bf14cec9ed142b9926", null ],
    [ "~VehicleGroupWindow", "d0/d27/classVehicleGroupWindow.html#a72ba6346db9ffc5b607c7695683f5082", null ],
    [ "AddChildren", "d0/d27/classVehicleGroupWindow.html#a2104925d445ee8ecee5defe79cd1e467", null ],
    [ "BuildGroupList", "d0/d27/classVehicleGroupWindow.html#a5c14ab151469edcca8efdedf142539a5", null ],
    [ "ComputeGroupInfoSize", "d0/d27/classVehicleGroupWindow.html#acbf383e4c59d565037de79166034a46a", null ],
    [ "DeleteGroupCallback", "d0/d27/classVehicleGroupWindow.html#ae756c6e6c2d737e39ff4e25f0f8419f2", null ],
    [ "DirtyHighlightedGroupWidget", "d0/d27/classVehicleGroupWindow.html#a1d41ba747a61bdd64ef9a0e8595c927e", null ],
    [ "DrawGroupInfo", "d0/d27/classVehicleGroupWindow.html#ad4381a4ad6131c1b9260c496118b44b3", null ],
    [ "DrawWidget", "d0/d27/classVehicleGroupWindow.html#a93585bd882b14c3ca649cd11be8e4d6f", null ],
    [ "GroupNameSorter", "d0/d27/classVehicleGroupWindow.html#abe5bf16f85c5df5c268db0c9f45d476b", null ],
    [ "OnClick", "d0/d27/classVehicleGroupWindow.html#ad92ed2b5315f15426e49b5a4eb4697f3", null ],
    [ "OnDragDrop", "d0/d27/classVehicleGroupWindow.html#a7627c6f34c127cbfdda1cc1b5e5fc232", null ],
    [ "OnDragDrop_Group", "d0/d27/classVehicleGroupWindow.html#aec667bcc36acf8971d5a9e0111a54542", null ],
    [ "OnDragDrop_Vehicle", "d0/d27/classVehicleGroupWindow.html#a64e3d19a55b81fee0dbdda81df93fd2a", null ],
    [ "OnDropdownSelect", "d0/d27/classVehicleGroupWindow.html#a155e99910c666e3205be9e8c2d35b7bd", null ],
    [ "OnGameTick", "d0/d27/classVehicleGroupWindow.html#a776cc578c8fbea5663a4ddd280d9c54b", null ],
    [ "OnInvalidateData", "d0/d27/classVehicleGroupWindow.html#ae2a2657590fece757d565ffe73ed39b9", null ],
    [ "OnMouseDrag", "d0/d27/classVehicleGroupWindow.html#a7ce9989d4d067e64af2828ad260153aa", null ],
    [ "OnPaint", "d0/d27/classVehicleGroupWindow.html#ac3596585c2fbd87429c2588d8d986a34", null ],
    [ "OnPlaceObjectAbort", "d0/d27/classVehicleGroupWindow.html#a914aeeb8309f919fbad3d1c76d52f66e", null ],
    [ "OnQueryTextFinished", "d0/d27/classVehicleGroupWindow.html#a357713af1ac308daf7677a709ca33ea7", null ],
    [ "OnResize", "d0/d27/classVehicleGroupWindow.html#a525f16783dae4a7c954064df7b75f730", null ],
    [ "SetStringParameters", "d0/d27/classVehicleGroupWindow.html#a2badc52e6fbaf24676e35004b1357637", null ],
    [ "ShowRenameGroupWindow", "d0/d27/classVehicleGroupWindow.html#a6d14aab2a50d138bbb7d1d787b3794c6", null ],
    [ "UnselectVehicle", "d0/d27/classVehicleGroupWindow.html#a1a18b2f2533c2355d46f0b53c88d29c1", null ],
    [ "UpdateWidgetSize", "d0/d27/classVehicleGroupWindow.html#a9638ef97c0bda9934468762d59823777", null ],
    [ "column_size", "d0/d27/classVehicleGroupWindow.html#ab062384e354f1ab3bd16eed32ad5d450", null ],
    [ "group_confirm", "d0/d27/classVehicleGroupWindow.html#ab5a474b4fd5bf7391e42308014fed740", null ],
    [ "group_over", "d0/d27/classVehicleGroupWindow.html#ac530fe653b342852e6780ed705e069ae", null ],
    [ "group_rename", "d0/d27/classVehicleGroupWindow.html#a4f5f7a1b1bc586a8c6b958d167218278", null ],
    [ "group_sb", "d0/d27/classVehicleGroupWindow.html#a6552351ea599e88e806fc0bb02f38428", null ],
    [ "group_sel", "d0/d27/classVehicleGroupWindow.html#a3c19708fe6f16d0c6665587cd9942838", null ],
    [ "groups", "d0/d27/classVehicleGroupWindow.html#ac35a03b61dd252174b6621f3a342829e", null ],
    [ "indents", "d0/d27/classVehicleGroupWindow.html#ace7632768268d30cb2e375c556a98080", null ],
    [ "tiny_step_height", "d0/d27/classVehicleGroupWindow.html#a692195262672eb258c542a8933213b76", null ],
    [ "vehicle_sel", "d0/d27/classVehicleGroupWindow.html#ac418630702a28dd3e918dd1637248b9f", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d0/d27/classVehicleGroupWindow.js <==
var classVehicleGroupWindow =
[
    [ "ListColumns", "d0/d27/classVehicleGroupWindow.html#ad4d7cb0ccb95e92e15690c8bf9f4716d", [
      [ "VGC_FOLD", "d0/d27/classVehicleGroupWindow.html#ad4d7cb0ccb95e92e15690c8bf9f4716da68a0abeefd2f9d539592df757fbd479d", null ],
      [ "VGC_NAME", "d0/d27/classVehicleGroupWindow.html#ad4d7cb0ccb95e92e15690c8bf9f4716da70b8b6aad8471d8e16cb47e0dfb5accf", null ],
      [ "VGC_PROTECT", "d0/d27/classVehicleGroupWindow.html#ad4d7cb0ccb95e92e15690c8bf9f4716da875b355759fe13acdcbb0fd2c62a4c50", null ],
      [ "VGC_AUTOREPLACE", "d0/d27/classVehicleGroupWindow.html#ad4d7cb0ccb95e92e15690c8bf9f4716da6187b84b9f40c7905f0ef8b7b5ef3a43", null ],
      [ "VGC_PROFIT", "d0/d27/classVehicleGroupWindow.html#ad4d7cb0ccb95e92e15690c8bf9f4716da5e1e385471ae13f1b57256439408c94d", null ],
      [ "VGC_NUMBER", "d0/d27/classVehicleGroupWindow.html#ad4d7cb0ccb95e92e15690c8bf9f4716dafd744d7ed56ce8ce9f6fe7661c740a06", null ],
      [ "VGC_END", "d0/d27/classVehicleGroupWindow.html#ad4d7cb0ccb95e92e15690c8bf9f4716da202d160f66f32764dae33bb5775f287e", null ]
    ] ],
    [ "VehicleGroupWindow", "d0/d27/classVehicleGroupWindow.html#aefbca24fd6c289bf14cec9ed142b9926", null ],
    [ "~VehicleGroupWindow", "d0/d27/classVehicleGroupWindow.html#a72ba6346db9ffc5b607c7695683f5082", null ],
    [ "AddChildren", "d0/d27/classVehicleGroupWindow.html#a2104925d445ee8ecee5defe79cd1e467", null ],
    [ "BuildGroupList", "d0/d27/classVehicleGroupWindow.html#a5c14ab151469edcca8efdedf142539a5", null ],
    [ "ComputeGroupInfoSize", "d0/d27/classVehicleGroupWindow.html#acbf383e4c59d565037de79166034a46a", null ],
    [ "DeleteGroupCallback", "d0/d27/classVehicleGroupWindow.html#ae756c6e6c2d737e39ff4e25f0f8419f2", null ],
    [ "DirtyHighlightedGroupWidget", "d0/d27/classVehicleGroupWindow.html#a1d41ba747a61bdd64ef9a0e8595c927e", null ],
    [ "DrawGroupInfo", "d0/d27/classVehicleGroupWindow.html#a396f5eaa15e79d4a3469e853dc19ad63", null ],
    [ "DrawWidget", "d0/d27/classVehicleGroupWindow.html#aaddde93cdc9226647a19a827c887aa33", null ],
    [ "OnClick", "d0/d27/classVehicleGroupWindow.html#a2dc3abc4ac45ad5441f6832d01bb5831", null ],
    [ "OnDragDrop", "d0/d27/classVehicleGroupWindow.html#ae4ca1ff111936cb715ce378a67178cfd", null ],
    [ "OnDragDrop_Group", "d0/d27/classVehicleGroupWindow.html#aec667bcc36acf8971d5a9e0111a54542", null ],
    [ "OnDragDrop_Vehicle", "d0/d27/classVehicleGroupWindow.html#a64e3d19a55b81fee0dbdda81df93fd2a", null ],
    [ "OnDropdownSelect", "d0/d27/classVehicleGroupWindow.html#a3097769ffd0a908a0cca749aa83ea557", null ],
    [ "OnGameTick", "d0/d27/classVehicleGroupWindow.html#a8c0a4f3bdcb8cff429704f7843d729d6", null ],
    [ "OnInvalidateData", "d0/d27/classVehicleGroupWindow.html#aca225827b9076c989e589b50813cd558", null ],
    [ "OnMouseDrag", "d0/d27/classVehicleGroupWindow.html#a987dca918915221495eb6da137849f6b", null ],
    [ "OnPaint", "d0/d27/classVehicleGroupWindow.html#afd74bc8da53a669bdcca70d445c77439", null ],
    [ "OnPlaceObjectAbort", "d0/d27/classVehicleGroupWindow.html#aaea2c19c209722f94388cec265185486", null ],
    [ "OnQueryTextFinished", "d0/d27/classVehicleGroupWindow.html#a522e083825007c0799ca42fe6c4c2940", null ],
    [ "OnResize", "d0/d27/classVehicleGroupWindow.html#a880c4408fa4f2930f28f79dcab98c023", null ],
    [ "SelectGroup", "d0/d27/classVehicleGroupWindow.html#af910fc27f1898715da32e1e7a1dda44f", null ],
    [ "SetStringParameters", "d0/d27/classVehicleGroupWindow.html#a8d10d78a85a98cfb7fa2dc5327f39039", null ],
    [ "ShowRenameGroupWindow", "d0/d27/classVehicleGroupWindow.html#a6d14aab2a50d138bbb7d1d787b3794c6", null ],
    [ "UnselectVehicle", "d0/d27/classVehicleGroupWindow.html#a1a18b2f2533c2355d46f0b53c88d29c1", null ],
    [ "UpdateWidgetSize", "d0/d27/classVehicleGroupWindow.html#ad61f78a9cc7405908a793e2f12ccf528", null ],
    [ "column_size", "d0/d27/classVehicleGroupWindow.html#ab062384e354f1ab3bd16eed32ad5d450", null ],
    [ "group_confirm", "d0/d27/classVehicleGroupWindow.html#ab5a474b4fd5bf7391e42308014fed740", null ],
    [ "group_over", "d0/d27/classVehicleGroupWindow.html#ac530fe653b342852e6780ed705e069ae", null ],
    [ "group_rename", "d0/d27/classVehicleGroupWindow.html#a4f5f7a1b1bc586a8c6b958d167218278", null ],
    [ "group_sb", "d0/d27/classVehicleGroupWindow.html#a6552351ea599e88e806fc0bb02f38428", null ],
    [ "group_sel", "d0/d27/classVehicleGroupWindow.html#a3c19708fe6f16d0c6665587cd9942838", null ],
    [ "groups", "d0/d27/classVehicleGroupWindow.html#ac35a03b61dd252174b6621f3a342829e", null ],
    [ "indents", "d0/d27/classVehicleGroupWindow.html#a417486b6d24c187dc3426f0ec136843c", null ],
    [ "tiny_step_height", "d0/d27/classVehicleGroupWindow.html#a692195262672eb258c542a8933213b76", null ],
    [ "vehicle_sel", "d0/d27/classVehicleGroupWindow.html#ac418630702a28dd3e918dd1637248b9f", null ]
];
